#!/usr/bin/env python
# -*- coding: utf-8 -*-
# generated by wxGlade 0.6.3 on Sun Jun 27 17:35:48 2010

import wx, os

from ObjectListView import FastObjectListView

from AIGO.gui.grid import StatisticsGrid

class ViewPanel(wx.Panel):
    def __init__(self, *args, **kwds):
        # content of this block not found: did you rename this class?
        pass

    def __set_properties(self):
        # content of this block not found: did you rename this class?
        pass

    def __do_layout(self):
        # content of this block not found: did you rename this class?
        pass

# end of class ViewPanel


class ViewFrame(wx.MDIChildFrame):
    def __init__(self, *args, **kwds):
        # begin wxGlade: ViewFrame.__init__
        kwds["style"] = wx.MINIMIZE_BOX|wx.MAXIMIZE_BOX|wx.STAY_ON_TOP|wx.RESIZE_BORDER|wx.FULL_REPAINT_ON_RESIZE
        wx.Frame.__init__(self, *args, **kwds)
        self.panel_2 = wx.Panel(self, -1)
        self.bitmap = wx.StaticBitmap(self.panel_2, -1, wx.NullBitmap, style=wx.FULL_REPAINT_ON_RESIZE)

        self.__set_properties()
        self.__do_layout()
        # end wxGlade

    def __set_properties(self):
        # begin wxGlade: ViewFrame.__set_properties
        self.SetTitle("View gene product")
        self.bitmap.SetMinSize((500,500))
        # end wxGlade

    def __do_layout(self):
        # begin wxGlade: ViewFrame.__do_layout
        sizer_34 = wx.BoxSizer(wx.VERTICAL)
        sizer_35 = wx.BoxSizer(wx.VERTICAL)
        sizer_35.Add(self.bitmap, 1, wx.EXPAND|wx.ALIGN_CENTER_HORIZONTAL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        self.panel_2.SetSizer(sizer_35)
        sizer_34.Add(self.panel_2, 1, wx.EXPAND|wx.ALIGN_CENTER_HORIZONTAL|wx.ALIGN_CENTER_VERTICAL, 0)
        self.SetSizer(sizer_34)
        sizer_34.Fit(self)
        self.Layout()
        self.Centre()
        # end wxGlade

# end of class ViewFrame


class FAFrame(wx.Frame):
    def __init__(self, *args, **kwds):
        # begin wxGlade: FAFrame.__init__
        kwds["style"] = wx.DEFAULT_FRAME_STYLE
        wx.Frame.__init__(self, *args, **kwds)
        self.panel_1 = wx.Panel(self, -1)
        self.sizer_11_staticbox = wx.StaticBox(self.panel_1, -1, "")
        self.label_FA = wx.StaticText(self.panel_1, -1, "FA name")
        self.box_FA = wx.TextCtrl(self.panel_1, -1, "", style=wx.HSCROLL)
        self.label_FA_File = wx.StaticText(self.panel_1, -1, "Choose file")
        self.box_File = wx.TextCtrl(self.panel_1, -1, "", style=wx.HSCROLL)
        self.button_FileChoose = wx.Button(self.panel_1, -1, "&Browse", style=wx.BU_EXACTFIT)
        self.label_FA_Type = wx.StaticText(self.panel_1, -1, "Choose file type")
        self.combo_box_FileType = wx.ComboBox(self.panel_1, -1, choices=["GO Annotation File", "Affymetrix", "Blast2GO", "ArrayIDer", "Mapping GPid GOids"], style=wx.CB_DROPDOWN)
        self.button_FAOK = wx.Button(self.panel_1, wx.ID_OK, "")
        self.button_FACancel = wx.Button(self.panel_1, wx.ID_CANCEL, "")

        self.__set_properties()
        self.__do_layout()
        # end wxGlade

    def __set_properties(self):
        # begin wxGlade: FAFrame.__set_properties
        self.SetTitle("New Functional Annotation")
        self.label_FA.SetMinSize((100, 19))
        self.box_FA.SetMinSize((360, 29))
        self.label_FA_File.SetMinSize((100, 19))
        self.box_File.SetMinSize((280, 29))
        self.combo_box_FileType.SetSelection(1)
        # end wxGlade

    def __do_layout(self):
        # begin wxGlade: FAFrame.__do_layout
        sizer_2 = wx.BoxSizer(wx.VERTICAL)
        sizer_8 = wx.BoxSizer(wx.VERTICAL)
        sizer_7_copy = wx.BoxSizer(wx.HORIZONTAL)
        sizer_11 = wx.StaticBoxSizer(self.sizer_11_staticbox, wx.VERTICAL)
        sizer_4_copy_2 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_4_copy_1 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_5_copy = wx.BoxSizer(wx.HORIZONTAL)
        sizer_5_copy.Add(self.label_FA, 0, 0, 0)
        sizer_5_copy.Add(self.box_FA, 0, wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_11.Add(sizer_5_copy, 0, wx.ALL|wx.EXPAND|wx.ALIGN_CENTER_VERTICAL|wx.SHAPED, 10)
        sizer_4_copy_1.Add(self.label_FA_File, 0, wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_4_copy_1.Add(self.box_File, 0, wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_4_copy_1.Add(self.button_FileChoose, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 10)
        sizer_11.Add(sizer_4_copy_1, 0, wx.ALL, 10)
        sizer_4_copy_2.Add(self.label_FA_Type, 0, wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_4_copy_2.Add(self.combo_box_FileType, 0, wx.ADJUST_MINSIZE, 0)
        sizer_11.Add(sizer_4_copy_2, 0, wx.ALL|wx.ALIGN_RIGHT, 10)
        sizer_8.Add(sizer_11, 0, wx.ALL|wx.EXPAND, 10)
        sizer_7_copy.Add(self.button_FAOK, 0, wx.BOTTOM|wx.ADJUST_MINSIZE, 10)
        sizer_7_copy.Add(self.button_FACancel, 0, wx.RIGHT|wx.BOTTOM|wx.ADJUST_MINSIZE, 10)
        sizer_8.Add(sizer_7_copy, 0, wx.ALIGN_RIGHT|wx.ALIGN_BOTTOM, 390)
        self.panel_1.SetSizer(sizer_8)
        sizer_2.Add(self.panel_1, 1, wx.EXPAND, 0)
        self.SetSizer(sizer_2)
        sizer_2.Fit(self)
        self.Layout()
        self.Centre()
        # end wxGlade

# end of class FAFrame


class AIGOnotebook(wx.Notebook):
    def __init__(self, *args, **kwds):
        # begin wxGlade: AIGOnotebook.__init__
        kwds["style"] = 0
        wx.Notebook.__init__(self, *args, **kwds)
        self.notebook_Plot = wx.Panel(self, -1)
        self.notebook_Compare = wx.Panel(self, -1)
        self.notebook_Compare_Aspect = wx.Notebook(self.notebook_Compare, -1, style=0)
        self.notebook_Compare_Aspect_pane_4 = wx.Panel(self.notebook_Compare_Aspect, -1)
        self.notebook_Compare_Aspect_pane_3 = wx.Panel(self.notebook_Compare_Aspect, -1)
        self.notebook_Compare_Aspect_pane_2 = wx.Panel(self.notebook_Compare_Aspect, -1)
        self.notebook_1_pane_1 = wx.Panel(self.notebook_Compare_Aspect, -1)
        self.notebook_Analysis = wx.Panel(self, -1)
        self.notebook_Statistics = wx.Notebook(self.notebook_Analysis, -1, style=wx.NB_LEFT)
        self.notebook_cellular_component = wx.Panel(self.notebook_Statistics, -1)
        self.notebook_molecular_function = wx.Panel(self.notebook_Statistics, -1)
        self.notebook_biological_process = wx.Panel(self.notebook_Statistics, -1)
        self.notebook_All_aspects_of_GO = wx.Panel(self.notebook_Statistics, -1)
        self.notebook_Data = wx.Panel(self, -1)
        self.sizer_GP_staticbox = wx.StaticBox(self.notebook_Data, -1, "Gene Products")
        self.sizer_FA_staticbox = wx.StaticBox(self.notebook_Data, -1, "Functional Annotations")
        self.sizer_16_staticbox = wx.StaticBox(self.notebook_Analysis, -1, "Statistics")
        self.sizer_27_copy_1_staticbox = wx.StaticBox(self.notebook_Compare, -1, "Select one or two Functional Annotations")
        self.sizer_31_staticbox = wx.StaticBox(self.notebook_Compare, -1, "Update information")
        self.sizer_27_copy_staticbox = wx.StaticBox(self.notebook_1_pane_1, -1, "")
        self.sizer_27_copy_copy_staticbox = wx.StaticBox(self.notebook_Compare_Aspect_pane_2, -1, "")
        self.sizer_27_copy_copy_1_staticbox = wx.StaticBox(self.notebook_Compare_Aspect_pane_3, -1, "")
        self.sizer_27_copy_copy_2_staticbox = wx.StaticBox(self.notebook_Compare_Aspect_pane_4, -1, "")
        self.sizer_23_staticbox = wx.StaticBox(self.notebook_Plot, -1, "")
        self.sizer_GO_staticbox = wx.StaticBox(self.notebook_Data, -1, "Gene Ontology")
        self.label_GO = wx.TextCtrl(self.notebook_Data, -1, "Choose the Gene Ontology", style=wx.TE_READONLY|wx.NO_BORDER)
        self.box_GO = wx.TextCtrl(self.notebook_Data, -1, "", style=wx.HSCROLL)
        self.button_GOChoose = wx.Button(self.notebook_Data, -1, "&Browse", style=wx.BU_EXACTFIT)
        self.button_GOLoad = wx.Button(self.notebook_Data, wx.ID_OPEN, "", style=wx.BU_EXACTFIT)
        self.radio_btn_GO = wx.RadioBox(self.notebook_Data, -1, "OBO format", choices=["XML", "Text"], majorDimension=1, style=wx.RA_SPECIFY_ROWS)
        self.checkbox_GO = wx.CheckBox(self.notebook_Data, -1, "Read previously serialised version")
        self.label_RefSet = wx.TextCtrl(self.notebook_Data, -1, "Choose the set of gene products", style=wx.TE_READONLY|wx.NO_BORDER)
        self.box_RefSet = wx.TextCtrl(self.notebook_Data, -1, "", style=wx.HSCROLL)
        self.button_RefSetChoose = wx.Button(self.notebook_Data, -1, "B&rowse", style=wx.BU_EXACTFIT)
        self.button_RefSetLoad = wx.Button(self.notebook_Data, wx.ID_OPEN, "", style=wx.BU_EXACTFIT)
        self.radio_btn_RefSet = wx.RadioBox(self.notebook_Data, -1, "File format", choices=["Fasta", "Text"], majorDimension=1, style=wx.RA_SPECIFY_ROWS)
        self.button_AddFA = wx.Button(self.notebook_Data, wx.ID_ADD, "")
        self.button_RemoveFA = wx.Button(self.notebook_Data, wx.ID_REMOVE, "")
        self.list_FA = wx.ListCtrl(self.notebook_Data, -1, style=wx.LC_REPORT|wx.SUNKEN_BORDER)
        self.button_LoadFA = wx.Button(self.notebook_Data, -1, "&Load")
        self.checkbox_unconnected = wx.CheckBox(self.notebook_Analysis, -1, "Obsolescence")
        self.label_unconnected = wx.StaticText(self.notebook_Analysis, -1, "Proportion of obsoletete annotations in annotation sets for which not alternative have been provided", style=wx.ALIGN_RIGHT)
        self.bitmap_unconnected = wx.StaticBitmap(self.notebook_Analysis, -1, wx.NullBitmap)
        self.checkbox_removeUnconnected = wx.CheckBox(self.notebook_Analysis, -1, "Remove Obsolete")
        self.label_removeUnconnected = wx.StaticText(self.notebook_Analysis, -1, "Remove obsolete annotations in all annotations sets", style=wx.ALIGN_RIGHT)
        self.bitmap_removeUnconnected = wx.StaticBitmap(self.notebook_Analysis, -1, wx.NullBitmap)
        self.checkbox_coverage = wx.CheckBox(self.notebook_Analysis, -1, "Coverage")
        self.label_coverage = wx.StaticText(self.notebook_Analysis, -1, "Proportion of gene products being annotated to at least on term", style=wx.ALIGN_RIGHT)
        self.bitmap_coverage = wx.StaticBitmap(self.notebook_Analysis, -1, wx.NullBitmap)
        self.checkbox_richness = wx.CheckBox(self.notebook_Analysis, -1, "Richness")
        self.label_richness = wx.StaticText(self.notebook_Analysis, -1, "Proportion of the terms in GO being assigned to at least one term", style=wx.ALIGN_RIGHT)
        self.bitmap_richness = wx.StaticBitmap(self.notebook_Analysis, -1, wx.NullBitmap)
        self.checkbox_numberAnnot = wx.CheckBox(self.notebook_Analysis, -1, "Number of Annotations")
        self.label_numberAnnot = wx.StaticText(self.notebook_Analysis, -1, "Number of annotation of an annotated gene product", style=wx.ALIGN_RIGHT)
        self.bitmap_numberAnnot = wx.StaticBitmap(self.notebook_Analysis, -1, wx.NullBitmap)
        self.checkbox_coherence = wx.CheckBox(self.notebook_Analysis, -1, "Coherence")
        self.label_coherence = wx.StaticText(self.notebook_Analysis, -1, "Semantic Distance of an annotation set", style=wx.ALIGN_RIGHT)
        self.bitmap_coherence = wx.StaticBitmap(self.notebook_Analysis, -1, wx.NullBitmap)
        self.checkbox_compactness = wx.CheckBox(self.notebook_Analysis, -1, "Compactness")
        self.label_compactness = wx.StaticText(self.notebook_Analysis, -1, "Semantic Distance between all annotation sets", style=wx.ALIGN_RIGHT)
        self.bitmap_compactness = wx.StaticBitmap(self.notebook_Analysis, -1, wx.NullBitmap)
        self.checkbox_specificity = wx.CheckBox(self.notebook_Analysis, -1, "Specificity")
        self.label_specificity = wx.StaticText(self.notebook_Analysis, -1, "Average number of ancestors over all the terms of an annotation set", style=wx.ALIGN_RIGHT)
        self.bitmap_specificity = wx.StaticBitmap(self.notebook_Analysis, -1, wx.NullBitmap)
        self.checkbox_informationContent = wx.CheckBox(self.notebook_Analysis, -1, "Information Content")
        self.label_informationContent = wx.StaticText(self.notebook_Analysis, -1, "Average Information Content over all the terms of an annotation set", style=wx.ALIGN_RIGHT)
        self.bitmap_informationContent = wx.StaticBitmap(self.notebook_Analysis, -1, wx.NullBitmap)
        self.checkbox_redundancy = wx.CheckBox(self.notebook_Analysis, -1, "Redundancy")
        self.label_redundancy = wx.StaticText(self.notebook_Analysis, -1, "Proportion of terms being ancestor one other term in an annotation set", style=wx.ALIGN_RIGHT)
        self.bitmap_redundancy = wx.StaticBitmap(self.notebook_Analysis, -1, wx.NullBitmap)
        self.button_Apply = wx.Button(self.notebook_Analysis, wx.ID_APPLY, "")
        self.grid_All_aspects_of_GO = StatisticsGrid(self.notebook_All_aspects_of_GO, -1, size=(1, 1))
        self.grid_biological_process = StatisticsGrid(self.notebook_biological_process, -1, size=(1, 1))
        self.grid_molecular_function = StatisticsGrid(self.notebook_molecular_function, -1, size=(1, 1))
        self.grid_cellular_component = StatisticsGrid(self.notebook_cellular_component, -1, size=(1, 1))
        self.button_Export = wx.Button(self.notebook_Analysis, wx.ID_FORWARD, "")
        self.combo_box_Compare_FA1 = wx.ComboBox(self.notebook_Compare, -1, choices=[], style=wx.CB_DROPDOWN|wx.CB_READONLY)
        self.combo_box_Compare_FA2 = wx.ComboBox(self.notebook_Compare, -1, choices=[], style=wx.CB_DROPDOWN|wx.CB_READONLY)
        self.button_Update_Venn = wx.Button(self.notebook_Compare, wx.ID_REFRESH, "")
        self.button_Update_FuncSim = wx.Button(self.notebook_Compare, wx.ID_REFRESH, "")
        self.bitmap_Venn_All_aspects_of_GO = wx.StaticBitmap(self.notebook_1_pane_1, -1, wx.NullBitmap)
        self.bitmap_All_aspects_of_GO = wx.StaticBitmap(self.notebook_1_pane_1, -1, wx.NullBitmap)
        self.bitmap_FuncSim_All_aspects_of_GO = wx.StaticBitmap(self.notebook_1_pane_1, -1, wx.NullBitmap)
        self.list_ctrl_Compare_All_aspects_of_GO = FastObjectListView(self.notebook_1_pane_1, -1, style=wx.LC_REPORT|wx.LC_SINGLE_SEL|wx.LC_SORT_ASCENDING|wx.LC_HRULES|wx.SUNKEN_BORDER)
        self.button_Compare_All_aspects_of_GO = wx.Button(self.notebook_1_pane_1, wx.ID_ZOOM_IN, "")
        self.bitmap_Venn_biological_process = wx.StaticBitmap(self.notebook_Compare_Aspect_pane_2, -1, wx.NullBitmap)
        self.bitmap_biological_process = wx.StaticBitmap(self.notebook_Compare_Aspect_pane_2, -1, wx.NullBitmap)
        self.bitmap_FuncSim_biological_process = wx.StaticBitmap(self.notebook_Compare_Aspect_pane_2, -1, wx.NullBitmap)
        self.list_ctrl_Compare_biological_process = FastObjectListView(self.notebook_Compare_Aspect_pane_2, -1, style=wx.LC_REPORT|wx.LC_SINGLE_SEL|wx.LC_SORT_ASCENDING|wx.LC_HRULES|wx.SUNKEN_BORDER)
        self.button_Compare_biological_process = wx.Button(self.notebook_Compare_Aspect_pane_2, wx.ID_ZOOM_IN, "")
        self.bitmap_Venn_molecular_function = wx.StaticBitmap(self.notebook_Compare_Aspect_pane_3, -1, wx.NullBitmap)
        self.bitmap_molecular_function = wx.StaticBitmap(self.notebook_Compare_Aspect_pane_3, -1, wx.NullBitmap)
        self.bitmap_FuncSim_molecular_function = wx.StaticBitmap(self.notebook_Compare_Aspect_pane_3, -1, wx.NullBitmap)
        self.list_ctrl_Compare_molecular_function = FastObjectListView(self.notebook_Compare_Aspect_pane_3, -1, style=wx.LC_REPORT|wx.LC_SINGLE_SEL|wx.LC_SORT_ASCENDING|wx.LC_HRULES|wx.SUNKEN_BORDER)
        self.button_Compare_molecular_function = wx.Button(self.notebook_Compare_Aspect_pane_3, wx.ID_ZOOM_IN, "")
        self.bitmap_Venn_cellular_component = wx.StaticBitmap(self.notebook_Compare_Aspect_pane_4, -1, wx.NullBitmap)
        self.bitmap_cellular_component = wx.StaticBitmap(self.notebook_Compare_Aspect_pane_4, -1, wx.NullBitmap)
        self.bitmap_FuncSim_cellular_component = wx.StaticBitmap(self.notebook_Compare_Aspect_pane_4, -1, wx.NullBitmap)
        self.list_ctrl_Compare_cellular_component = FastObjectListView(self.notebook_Compare_Aspect_pane_4, -1, style=wx.LC_REPORT|wx.LC_SINGLE_SEL|wx.LC_SORT_ASCENDING|wx.LC_HRULES|wx.SUNKEN_BORDER)
        self.button_Compare_cellular_component = wx.Button(self.notebook_Compare_Aspect_pane_4, wx.ID_ZOOM_IN, "")
        self.label_PlotStatistics = wx.StaticText(self.notebook_Plot, -1, "Select a statistics")
        self.combo_PlotStat = wx.ComboBox(self.notebook_Plot, -1, choices=[], style=wx.CB_DROPDOWN)
        self.label_2 = wx.StaticText(self.notebook_Plot, -1, "Plot type")
        self.combo_PlotType = wx.ComboBox(self.notebook_Plot, -1, choices=[], style=wx.CB_DROPDOWN)
        self.label_PlotStatistics_copy = wx.StaticText(self.notebook_Plot, -1, "Select Functional Annotations")
        self.list_PlotFA = wx.ListBox(self.notebook_Plot, -1, choices=[], style=wx.LB_MULTIPLE|wx.LB_HSCROLL|wx.LB_NEEDED_SB)
        self.bitmap_Plot = wx.StaticBitmap(self.notebook_Plot, -1, wx.NullBitmap, style=wx.RAISED_BORDER)

        self.__set_properties()
        self.__do_layout()
        # end wxGlade

    def __set_properties(self):
        # begin wxGlade: AIGOnotebook.__set_properties
        self.AddPage(self.notebook_Data, "Data")
        self.AddPage(self.notebook_Analysis, "Analysis")
        self.AddPage(self.notebook_Compare, "Compare")
        self.AddPage(self.notebook_Plot, "Plot")
        self.label_GO.SetMinSize((280, 29))
        self.label_GO.SetBackgroundColour(wx.Colour(241, 238, 238))
        self.box_GO.SetMinSize((280, 29))
        self.radio_btn_GO.Enable(False)
        self.radio_btn_GO.SetSelection(0)
        self.checkbox_GO.Hide()
        self.label_RefSet.SetMinSize((280, 29))
        self.label_RefSet.SetBackgroundColour(wx.Colour(241, 238, 238))
        self.box_RefSet.SetMinSize((280, 29))
        self.radio_btn_RefSet.SetSelection(0)
        self.button_AddFA.Enable(False)
        self.button_RemoveFA.Enable(False)
        self.notebook_Data.SetBackgroundColour(wx.Colour(241, 238, 238))
        self.notebook_Data.Enable(False)
        self.checkbox_unconnected.SetValue(1)
        self.checkbox_removeUnconnected.SetValue(1)
        self.checkbox_coverage.SetValue(1)
        self.checkbox_richness.SetValue(1)
        self.checkbox_numberAnnot.SetValue(1)
        self.checkbox_coherence.SetValue(1)
        self.checkbox_compactness.SetValue(1)
        self.checkbox_specificity.SetValue(1)
        self.checkbox_informationContent.SetValue(1)
        self.checkbox_redundancy.SetValue(1)
        self.grid_All_aspects_of_GO.CreateGrid(10, 3)
        self.grid_All_aspects_of_GO.SetRowLabelSize(250)
        self.grid_All_aspects_of_GO.SetColLabelSize(30)
        self.grid_All_aspects_of_GO.EnableEditing(0)
        self.grid_biological_process.CreateGrid(10, 3)
        self.grid_biological_process.SetRowLabelSize(250)
        self.grid_biological_process.EnableEditing(0)
        self.grid_molecular_function.CreateGrid(10, 3)
        self.grid_molecular_function.SetRowLabelSize(250)
        self.grid_molecular_function.EnableEditing(0)
        self.grid_cellular_component.CreateGrid(10, 3)
        self.grid_cellular_component.SetRowLabelSize(250)
        self.grid_cellular_component.EnableEditing(0)
        self.button_Update_Venn.SetMinSize((189, 34))
        self.button_Update_FuncSim.SetMinSize((189, 34))
        self.bitmap_Venn_All_aspects_of_GO.SetMinSize((369, 280))
        self.bitmap_All_aspects_of_GO.SetMinSize((369, 280))
        self.bitmap_FuncSim_All_aspects_of_GO.SetMinSize((369, 280))
        self.list_ctrl_Compare_All_aspects_of_GO.SetMinSize((1100, 270))
        self.list_ctrl_Compare_All_aspects_of_GO.Enable(False)
        self.list_ctrl_Compare_All_aspects_of_GO.Hide()
        self.button_Compare_All_aspects_of_GO.Enable(False)
        self.button_Compare_All_aspects_of_GO.Hide()
        self.bitmap_Venn_biological_process.SetMinSize((369, 280))
        self.bitmap_biological_process.SetMinSize((369, 280))
        self.bitmap_FuncSim_biological_process.SetMinSize((369, 280))
        self.list_ctrl_Compare_biological_process.SetMinSize((1100, 270))
        self.bitmap_Venn_molecular_function.SetMinSize((369, 280))
        self.bitmap_molecular_function.SetMinSize((369, 280))
        self.bitmap_FuncSim_molecular_function.SetMinSize((369, 280))
        self.list_ctrl_Compare_molecular_function.SetMinSize((1100, 270))
        self.bitmap_Venn_cellular_component.SetMinSize((369, 280))
        self.bitmap_cellular_component.SetMinSize((369, 280))
        self.bitmap_FuncSim_cellular_component.SetMinSize((369, 280))
        self.list_ctrl_Compare_cellular_component.SetMinSize((1100, 270))
        self.notebook_Compare.Enable(False)
        self.combo_PlotType.SetMinSize((250, 31))
        self.notebook_Plot.Enable(False)
        # end wxGlade

    def __do_layout(self):
        # begin wxGlade: AIGOnotebook.__do_layout
        sizer_17 = wx.BoxSizer(wx.VERTICAL)
        sizer_24 = wx.BoxSizer(wx.VERTICAL)
        sizer_23 = wx.StaticBoxSizer(self.sizer_23_staticbox, wx.VERTICAL)
        sizer_25 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_30 = wx.BoxSizer(wx.VERTICAL)
        sizer_28 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_26 = wx.BoxSizer(wx.VERTICAL)
        sizer_26_copy_copy_2 = wx.BoxSizer(wx.VERTICAL)
        sizer_27_copy_copy_2 = wx.StaticBoxSizer(self.sizer_27_copy_copy_2_staticbox, wx.HORIZONTAL)
        sizer_26_copy_copy_1 = wx.BoxSizer(wx.VERTICAL)
        sizer_27_copy_copy_1 = wx.StaticBoxSizer(self.sizer_27_copy_copy_1_staticbox, wx.HORIZONTAL)
        sizer_26_copy_copy = wx.BoxSizer(wx.VERTICAL)
        sizer_27_copy_copy = wx.StaticBoxSizer(self.sizer_27_copy_copy_staticbox, wx.HORIZONTAL)
        sizer_26_copy = wx.BoxSizer(wx.VERTICAL)
        sizer_27_copy = wx.StaticBoxSizer(self.sizer_27_copy_staticbox, wx.HORIZONTAL)
        sizer_27 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_31 = wx.StaticBoxSizer(self.sizer_31_staticbox, wx.HORIZONTAL)
        sizer_32 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_27_copy_1 = wx.StaticBoxSizer(self.sizer_27_copy_1_staticbox, wx.HORIZONTAL)
        sizer_10 = wx.BoxSizer(wx.VERTICAL)
        sizer_15 = wx.BoxSizer(wx.VERTICAL)
        sizer_18 = wx.BoxSizer(wx.VERTICAL)
        sizer_22 = wx.BoxSizer(wx.VERTICAL)
        sizer_21 = wx.BoxSizer(wx.VERTICAL)
        sizer_20 = wx.BoxSizer(wx.VERTICAL)
        sizer_19 = wx.BoxSizer(wx.VERTICAL)
        sizer_16 = wx.StaticBoxSizer(self.sizer_16_staticbox, wx.VERTICAL)
        grid_sizer_2 = wx.FlexGridSizer(10, 3, 0, 20)
        sizer_3 = wx.BoxSizer(wx.VERTICAL)
        sizer_FA = wx.StaticBoxSizer(self.sizer_FA_staticbox, wx.VERTICAL)
        grid_sizer_1 = wx.GridSizer(1, 2, 0, 0)
        sizer_GP = wx.StaticBoxSizer(self.sizer_GP_staticbox, wx.VERTICAL)
        sizer_12_copy = wx.BoxSizer(wx.HORIZONTAL)
        sizer_4 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_GO = wx.StaticBoxSizer(self.sizer_GO_staticbox, wx.VERTICAL)
        sizer_12_copy_copy = wx.BoxSizer(wx.HORIZONTAL)
        sizer_4_copy = wx.BoxSizer(wx.HORIZONTAL)
        sizer_4_copy.Add(self.label_GO, 0, wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_4_copy.Add((40, 40), 0, wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_4_copy.Add(self.box_GO, 0, wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_4_copy.Add(self.button_GOChoose, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_4_copy.Add(self.button_GOLoad, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_GO.Add(sizer_4_copy, 0, wx.ALL, 5)
        sizer_12_copy_copy.Add((400, 46), 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_12_copy_copy.Add(self.radio_btn_GO, 0, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL|wx.ALIGN_CENTER_VERTICAL, 5)
        sizer_12_copy_copy.Add(self.checkbox_GO, 0, wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_GO.Add(sizer_12_copy_copy, 0, wx.ALL, 5)
        sizer_3.Add(sizer_GO, 0, wx.ALL|wx.EXPAND, 5)
        sizer_4.Add(self.label_RefSet, 0, wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_4.Add((40, 40), 0, wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_4.Add(self.box_RefSet, 0, wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_4.Add(self.button_RefSetChoose, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_4.Add(self.button_RefSetLoad, 0, wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_GP.Add(sizer_4, 0, wx.ALL, 5)
        sizer_12_copy.Add((400, 46), 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_12_copy.Add(self.radio_btn_RefSet, 0, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL|wx.ALIGN_CENTER_VERTICAL, 5)
        sizer_GP.Add(sizer_12_copy, 0, wx.ALL, 5)
        sizer_3.Add(sizer_GP, 0, wx.ALL|wx.EXPAND, 5)
        grid_sizer_1.Add(self.button_AddFA, 0, wx.ADJUST_MINSIZE, 0)
        grid_sizer_1.Add(self.button_RemoveFA, 0, wx.ADJUST_MINSIZE, 0)
        sizer_FA.Add(grid_sizer_1, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 10)
        sizer_FA.Add(self.list_FA, 1, wx.EXPAND, 0)
        sizer_FA.Add(self.button_LoadFA, 0, wx.ALIGN_RIGHT|wx.ADJUST_MINSIZE, 0)
        sizer_3.Add(sizer_FA, 1, wx.ALL|wx.EXPAND|wx.ADJUST_MINSIZE, 5)
        self.notebook_Data.SetSizer(sizer_3)
        grid_sizer_2.Add(self.checkbox_unconnected, 0, wx.ADJUST_MINSIZE, 5)
        grid_sizer_2.Add(self.label_unconnected, 0, wx.EXPAND|wx.ALIGN_CENTER_VERTICAL, 5)
        grid_sizer_2.Add(self.bitmap_unconnected, 0, wx.ADJUST_MINSIZE, 0)
        grid_sizer_2.Add(self.checkbox_removeUnconnected, 0, wx.ADJUST_MINSIZE, 5)
        grid_sizer_2.Add(self.label_removeUnconnected, 0, wx.EXPAND|wx.ALIGN_CENTER_VERTICAL, 0)
        grid_sizer_2.Add(self.bitmap_removeUnconnected, 0, wx.ADJUST_MINSIZE, 0)
        grid_sizer_2.Add(self.checkbox_coverage, 0, wx.ADJUST_MINSIZE, 5)
        grid_sizer_2.Add(self.label_coverage, 0, wx.EXPAND|wx.ALIGN_CENTER_VERTICAL, 0)
        grid_sizer_2.Add(self.bitmap_coverage, 0, wx.ADJUST_MINSIZE, 0)
        grid_sizer_2.Add(self.checkbox_richness, 0, wx.ADJUST_MINSIZE, 5)
        grid_sizer_2.Add(self.label_richness, 0, wx.EXPAND|wx.ALIGN_CENTER_VERTICAL, 0)
        grid_sizer_2.Add(self.bitmap_richness, 0, wx.ADJUST_MINSIZE, 0)
        grid_sizer_2.Add(self.checkbox_numberAnnot, 0, wx.ADJUST_MINSIZE, 5)
        grid_sizer_2.Add(self.label_numberAnnot, 0, wx.EXPAND|wx.ALIGN_CENTER_VERTICAL, 0)
        grid_sizer_2.Add(self.bitmap_numberAnnot, 0, wx.ADJUST_MINSIZE, 0)
        grid_sizer_2.Add(self.checkbox_coherence, 0, wx.ADJUST_MINSIZE, 5)
        grid_sizer_2.Add(self.label_coherence, 0, wx.EXPAND|wx.ALIGN_CENTER_VERTICAL, 0)
        grid_sizer_2.Add(self.bitmap_coherence, 0, wx.ADJUST_MINSIZE, 0)
        grid_sizer_2.Add(self.checkbox_compactness, 0, wx.ADJUST_MINSIZE, 5)
        grid_sizer_2.Add(self.label_compactness, 0, wx.EXPAND|wx.ALIGN_CENTER_VERTICAL, 0)
        grid_sizer_2.Add(self.bitmap_compactness, 0, wx.ADJUST_MINSIZE, 0)
        grid_sizer_2.Add(self.checkbox_specificity, 0, wx.ADJUST_MINSIZE, 5)
        grid_sizer_2.Add(self.label_specificity, 0, wx.EXPAND|wx.ALIGN_CENTER_VERTICAL, 0)
        grid_sizer_2.Add(self.bitmap_specificity, 0, wx.ADJUST_MINSIZE, 0)
        grid_sizer_2.Add(self.checkbox_informationContent, 0, wx.ADJUST_MINSIZE, 5)
        grid_sizer_2.Add(self.label_informationContent, 0, wx.EXPAND|wx.ALIGN_CENTER_VERTICAL, 0)
        grid_sizer_2.Add(self.bitmap_informationContent, 0, wx.ADJUST_MINSIZE, 0)
        grid_sizer_2.Add(self.checkbox_redundancy, 0, wx.ADJUST_MINSIZE, 5)
        grid_sizer_2.Add(self.label_redundancy, 0, wx.EXPAND|wx.ALIGN_CENTER_VERTICAL, 0)
        grid_sizer_2.Add(self.bitmap_redundancy, 0, wx.ADJUST_MINSIZE, 0)
        sizer_16.Add(grid_sizer_2, 0, wx.EXPAND, 0)
        sizer_16.Add(self.button_Apply, 0, wx.ALL|wx.ALIGN_RIGHT|wx.ADJUST_MINSIZE, 5)
        sizer_15.Add(sizer_16, 0, wx.ALL|wx.EXPAND, 5)
        sizer_19.Add(self.grid_All_aspects_of_GO, 1, wx.EXPAND|wx.ADJUST_MINSIZE, 0)
        self.notebook_All_aspects_of_GO.SetSizer(sizer_19)
        sizer_20.Add(self.grid_biological_process, 1, wx.EXPAND|wx.ADJUST_MINSIZE, 0)
        self.notebook_biological_process.SetSizer(sizer_20)
        sizer_21.Add(self.grid_molecular_function, 1, wx.EXPAND|wx.ADJUST_MINSIZE, 0)
        self.notebook_molecular_function.SetSizer(sizer_21)
        sizer_22.Add(self.grid_cellular_component, 1, wx.EXPAND|wx.ADJUST_MINSIZE, 0)
        self.notebook_cellular_component.SetSizer(sizer_22)
        self.notebook_Statistics.AddPage(self.notebook_All_aspects_of_GO, "All aspects of GO")
        self.notebook_Statistics.AddPage(self.notebook_biological_process, "Biological Process")
        self.notebook_Statistics.AddPage(self.notebook_molecular_function, "Molecular Function")
        self.notebook_Statistics.AddPage(self.notebook_cellular_component, "Cellular Component")
        sizer_18.Add(self.notebook_Statistics, 1, wx.EXPAND|wx.ADJUST_MINSIZE, 0)
        sizer_18.Add(self.button_Export, 0, wx.ALL|wx.ALIGN_RIGHT|wx.ADJUST_MINSIZE, 5)
        sizer_15.Add(sizer_18, 1, wx.ALL|wx.EXPAND|wx.ADJUST_MINSIZE, 5)
        sizer_10.Add(sizer_15, 1, wx.EXPAND, 0)
        self.notebook_Analysis.SetSizer(sizer_10)
        sizer_27_copy_1.Add(self.combo_box_Compare_FA1, 0, wx.ALL|wx.ADJUST_MINSIZE, 5)
        sizer_27_copy_1.Add(self.combo_box_Compare_FA2, 0, wx.ALL|wx.ADJUST_MINSIZE, 5)
        sizer_27.Add(sizer_27_copy_1, 1, wx.ALL|wx.EXPAND, 5)
        sizer_32.Add(self.button_Update_Venn, 0, wx.ALL|wx.ALIGN_RIGHT|wx.ADJUST_MINSIZE, 5)
        sizer_32.Add(self.button_Update_FuncSim, 0, wx.ALL|wx.ALIGN_RIGHT|wx.ADJUST_MINSIZE, 5)
        sizer_31.Add(sizer_32, 1, wx.EXPAND|wx.ALIGN_RIGHT, 0)
        sizer_27.Add(sizer_31, 1, wx.ALL|wx.EXPAND|wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL, 5)
        sizer_26.Add(sizer_27, 0, wx.EXPAND, 0)
        sizer_27_copy.Add(self.bitmap_Venn_All_aspects_of_GO, 1, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 1)
        sizer_27_copy.Add(self.bitmap_All_aspects_of_GO, 1, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 1)
        sizer_27_copy.Add(self.bitmap_FuncSim_All_aspects_of_GO, 1, wx.ALL|wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 1)
        sizer_26_copy.Add(sizer_27_copy, 0, wx.ALL|wx.EXPAND, 5)
        sizer_26_copy.Add(self.list_ctrl_Compare_All_aspects_of_GO, 0, wx.ALL|wx.EXPAND, 5)
        sizer_26_copy.Add(self.button_Compare_All_aspects_of_GO, 0, wx.ALL|wx.ALIGN_RIGHT|wx.ADJUST_MINSIZE, 5)
        self.notebook_1_pane_1.SetSizer(sizer_26_copy)
        sizer_27_copy_copy.Add(self.bitmap_Venn_biological_process, 1, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 1)
        sizer_27_copy_copy.Add(self.bitmap_biological_process, 1, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 1)
        sizer_27_copy_copy.Add(self.bitmap_FuncSim_biological_process, 1, wx.ALL|wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 1)
        sizer_26_copy_copy.Add(sizer_27_copy_copy, 0, wx.ALL|wx.EXPAND, 5)
        sizer_26_copy_copy.Add(self.list_ctrl_Compare_biological_process, 0, wx.ALL|wx.EXPAND, 5)
        sizer_26_copy_copy.Add(self.button_Compare_biological_process, 0, wx.ALL|wx.ALIGN_RIGHT|wx.ADJUST_MINSIZE, 5)
        self.notebook_Compare_Aspect_pane_2.SetSizer(sizer_26_copy_copy)
        sizer_27_copy_copy_1.Add(self.bitmap_Venn_molecular_function, 1, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 1)
        sizer_27_copy_copy_1.Add(self.bitmap_molecular_function, 1, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 1)
        sizer_27_copy_copy_1.Add(self.bitmap_FuncSim_molecular_function, 1, wx.ALL|wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 1)
        sizer_26_copy_copy_1.Add(sizer_27_copy_copy_1, 0, wx.ALL|wx.EXPAND, 5)
        sizer_26_copy_copy_1.Add(self.list_ctrl_Compare_molecular_function, 0, wx.ALL|wx.EXPAND, 5)
        sizer_26_copy_copy_1.Add(self.button_Compare_molecular_function, 0, wx.ALL|wx.ALIGN_RIGHT|wx.ADJUST_MINSIZE, 5)
        self.notebook_Compare_Aspect_pane_3.SetSizer(sizer_26_copy_copy_1)
        sizer_27_copy_copy_2.Add(self.bitmap_Venn_cellular_component, 1, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 1)
        sizer_27_copy_copy_2.Add(self.bitmap_cellular_component, 1, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 1)
        sizer_27_copy_copy_2.Add(self.bitmap_FuncSim_cellular_component, 1, wx.ALL|wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 1)
        sizer_26_copy_copy_2.Add(sizer_27_copy_copy_2, 0, wx.ALL|wx.EXPAND, 5)
        sizer_26_copy_copy_2.Add(self.list_ctrl_Compare_cellular_component, 0, wx.ALL|wx.EXPAND, 5)
        sizer_26_copy_copy_2.Add(self.button_Compare_cellular_component, 0, wx.ALL|wx.ALIGN_RIGHT|wx.ADJUST_MINSIZE, 5)
        self.notebook_Compare_Aspect_pane_4.SetSizer(sizer_26_copy_copy_2)
        self.notebook_Compare_Aspect.AddPage(self.notebook_1_pane_1, "All aspects of GO")
        self.notebook_Compare_Aspect.AddPage(self.notebook_Compare_Aspect_pane_2, "Biological Process")
        self.notebook_Compare_Aspect.AddPage(self.notebook_Compare_Aspect_pane_3, "Molecular Function")
        self.notebook_Compare_Aspect.AddPage(self.notebook_Compare_Aspect_pane_4, "Cellular component")
        sizer_26.Add(self.notebook_Compare_Aspect, 0, wx.ALL|wx.EXPAND, 5)
        self.notebook_Compare.SetSizer(sizer_26)
        sizer_25.Add(self.label_PlotStatistics, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 5)
        sizer_25.Add(self.combo_PlotStat, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 5)
        sizer_28.Add(self.label_2, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 5)
        sizer_28.Add(self.combo_PlotType, 0, wx.ALL|wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 5)
        sizer_25.Add(sizer_28, 0, wx.EXPAND, 0)
        sizer_30.Add(self.label_PlotStatistics_copy, 0, wx.ALL|wx.ADJUST_MINSIZE, 5)
        sizer_30.Add(self.list_PlotFA, 0, wx.ALL|wx.EXPAND|wx.ADJUST_MINSIZE, 5)
        sizer_25.Add(sizer_30, 1, wx.EXPAND, 0)
        sizer_23.Add(sizer_25, 0, wx.EXPAND, 0)
        sizer_17.Add(sizer_23, 0, wx.ALL|wx.EXPAND, 5)
        sizer_24.Add(self.bitmap_Plot, 0, wx.ALL|wx.ALIGN_CENTER_HORIZONTAL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 5)
        sizer_17.Add(sizer_24, 1, wx.ALL|wx.EXPAND, 5)
        self.notebook_Plot.SetSizer(sizer_17)
        # end wxGlade

# end of class AIGOnotebook


class AIGOFrame(wx.Frame):
    def __init__(self, *args, **kwds):
        # begin wxGlade: AIGOFrame.__init__
        kwds["style"] = wx.CAPTION|wx.CLOSE_BOX|wx.MINIMIZE_BOX|wx.MAXIMIZE|wx.MAXIMIZE_BOX|wx.SYSTEM_MENU|wx.TAB_TRAVERSAL|wx.CLIP_CHILDREN
        wx.Frame.__init__(self, *args, **kwds)
        
        # Menu Bar
        self.menubar = wx.MenuBar()
        global MENU_NEW; MENU_NEW = wx.NewId()
        global MENU_OPEN; MENU_OPEN = wx.NewId()
        global MENU_SAVE; MENU_SAVE = wx.NewId()
        global MENU_QUIT; MENU_QUIT = wx.NewId()
        global MENU_ABOUT; MENU_ABOUT = wx.NewId()
        self.ProjectMenu = wx.Menu()
        self.ProjectMenu.Append(MENU_NEW, "New", "", wx.ITEM_NORMAL)
        self.ProjectMenu.Append(MENU_OPEN, "Open", "", wx.ITEM_NORMAL)
        self.ProjectMenu.Append(MENU_SAVE, "Save", "", wx.ITEM_NORMAL)
        self.ProjectMenu.Append(MENU_QUIT, "Quit", "", wx.ITEM_NORMAL)
        self.menubar.Append(self.ProjectMenu, "&Project")
        wxglade_tmp_menu = wx.Menu()
        wxglade_tmp_menu.AppendSeparator()
        wxglade_tmp_menu.Append(MENU_ABOUT, "About", "", wx.ITEM_NORMAL)
        self.menubar.Append(wxglade_tmp_menu, "Help")
        self.SetMenuBar(self.menubar)
        # Menu Bar end
        self.statusbar = self.CreateStatusBar(6, wx.ST_SIZEGRIP)
        self.notebook = AIGOnotebook(self, -1)

        self.__set_properties()
        self.__do_layout()
        # end wxGlade

    def __set_properties(self):
        # begin wxGlade: AIGOFrame.__set_properties
        self.SetTitle("AIGO")
        _icon = wx.EmptyIcon()
        import os
        import AIGO.gui
        guiDir=os.path.dirname(AIGO.gui.__file__)
        _icon.CopyFromBitmap(wx.Bitmap("%s/AIGO.png" % guiDir, wx.BITMAP_TYPE_ANY))
        self.SetIcon(_icon)
        self.SetSize((1156, 835))
        self.statusbar.SetStatusWidths([-1, -1, -1, -1, -1, -1])
        # statusbar fields
        statusbar_fields = ["Project", "Status", "Organism", "GO", "GP", "FA"]
        for i in range(len(statusbar_fields)):
            self.statusbar.SetStatusText(statusbar_fields[i], i)
        # end wxGlade

    def __do_layout(self):
        # begin wxGlade: AIGOFrame.__do_layout
        sizer_1 = wx.BoxSizer(wx.VERTICAL)
        sizer_1.Add(self.notebook, 1, wx.EXPAND|wx.ADJUST_MINSIZE, 0)
        self.SetSizer(sizer_1)
        self.Layout()
        # end wxGlade

# end of class AIGOFrame


class NewProjectFrame(wx.Frame):
    def __init__(self, *args, **kwds):
        # begin wxGlade: NewProjectFrame.__init__
        kwds["style"] = wx.DEFAULT_FRAME_STYLE
        wx.Frame.__init__(self, *args, **kwds)
        self.NewProjectPanel = wx.Panel(self, -1)
        self.sizer_12_staticbox = wx.StaticBox(self.NewProjectPanel, -1, "")
        self.sizer_9_staticbox = wx.StaticBox(self.NewProjectPanel, -1, "")
        self.label_NewProject = wx.StaticText(self.NewProjectPanel, -1, "Project name")
        self.box_NewProject = wx.TextCtrl(self.NewProjectPanel, -1, "", style=wx.HSCROLL)
        self.label_Directory = wx.StaticText(self.NewProjectPanel, -1, "Project directory")
        self.box_Directory = wx.TextCtrl(self.NewProjectPanel, -1, "", style=wx.HSCROLL)
        self.button_DirectoryChoose = wx.Button(self.NewProjectPanel, -1, "&Browse", style=wx.BU_EXACTFIT)
        self.label_Organism = wx.StaticText(self.NewProjectPanel, -1, "Reference Organism")
        self.box_Organism = wx.TextCtrl(self.NewProjectPanel, -1, "", style=wx.HSCROLL)
        self.button_NewProjectOK = wx.Button(self.NewProjectPanel, wx.ID_OK, "")
        self.button_NewProjectCancel = wx.Button(self.NewProjectPanel, wx.ID_CANCEL, "")

        self.__set_properties()
        self.__do_layout()
        # end wxGlade

    def __set_properties(self):
        # begin wxGlade: NewProjectFrame.__set_properties
        self.SetTitle("New Project")
        self.label_NewProject.SetMinSize((165, 19))
        self.box_NewProject.SetMinSize((360, 29))
        self.label_Directory.SetMinSize((165, 19))
        self.box_Directory.SetMinSize((280, 29))
        self.label_Organism.SetMinSize((165, 19))
        self.box_Organism.SetMinSize((360, 29))
        self.NewProjectPanel.SetBackgroundColour(wx.Colour(241, 238, 238))
        # end wxGlade

    def __do_layout(self):
        # begin wxGlade: NewProjectFrame.__do_layout
        sizer_13 = wx.BoxSizer(wx.VERTICAL)
        sizer_14 = wx.BoxSizer(wx.VERTICAL)
        sizer_7 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_12 = wx.StaticBoxSizer(self.sizer_12_staticbox, wx.VERTICAL)
        sizer_6 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_9 = wx.StaticBoxSizer(self.sizer_9_staticbox, wx.VERTICAL)
        sizer_4_copy_3 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_5 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_5.Add(self.label_NewProject, 0, 0, 0)
        sizer_5.Add(self.box_NewProject, 0, wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_9.Add(sizer_5, 0, wx.ALL|wx.EXPAND|wx.ALIGN_CENTER_VERTICAL|wx.SHAPED, 10)
        sizer_4_copy_3.Add(self.label_Directory, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_4_copy_3.Add(self.box_Directory, 0, wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_4_copy_3.Add(self.button_DirectoryChoose, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 10)
        sizer_9.Add(sizer_4_copy_3, 0, wx.ALL, 10)
        sizer_14.Add(sizer_9, 0, wx.ALL|wx.EXPAND, 10)
        sizer_6.Add(self.label_Organism, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_6.Add(self.box_Organism, 0, wx.ALIGN_CENTER_VERTICAL|wx.ADJUST_MINSIZE, 0)
        sizer_12.Add(sizer_6, 0, wx.ALL, 10)
        sizer_14.Add(sizer_12, 1, wx.ALL|wx.EXPAND, 10)
        sizer_7.Add(self.button_NewProjectOK, 0, wx.BOTTOM|wx.ADJUST_MINSIZE, 10)
        sizer_7.Add(self.button_NewProjectCancel, 0, wx.RIGHT|wx.BOTTOM|wx.ADJUST_MINSIZE, 10)
        sizer_14.Add(sizer_7, 0, wx.LEFT|wx.EXPAND|wx.ALIGN_BOTTOM, 390)
        self.NewProjectPanel.SetSizer(sizer_14)
        sizer_13.Add(self.NewProjectPanel, 1, wx.EXPAND, 0)
        self.SetSizer(sizer_13)
        sizer_13.Fit(self)
        self.Layout()
        self.Centre()
        # end wxGlade

# end of class NewProjectFrame


if __name__ == "__main__":
    AIGO = wx.PySimpleApp(0)
    wx.InitAllImageHandlers()
    Frame = AIGOFrame(None, -1, "")
    AIGO.SetTopWindow(Frame)
    Frame.Show()
    AIGO.MainLoop()
